@@ -15,7 +15,7 @@ from edc_sites.models import SiteProfile
 from faker import Faker
 from mempass import mkpassword
 
-from edc_auth.auth_objects import CLINICIAN_ROLE
+from edc_auth.constants import CLINICIAN_ROLE
 from edc_auth.site_auths import site_auths
 from edc_auth.tests.randomizers import CustomRandomizer
 
@@ -45,10 +45,11 @@ class EdcAuthTestCase(TestCase):
 
 def create_users(count=None, group_name=None, site_name=None):
     usernames = []
-    for _ in range(0, count or 2):
+    User.objects.all().delete()
+    for index in range(0, count or 2):
         first_name = fake.first_name()
-        last_name = fake.last_name()
-        username = (first_name[0] + last_name).lower()
+        last_name = fake.last_name() + str(index)
+        username = (first_name[0] + last_name).lower() + str(index)
         user_data = {
             "username": username,
             "first_name": first_name,
