@@ -1,21 +1,27 @@
 #!/usr/bin/env python
 import logging
-from os.path import abspath, dirname
+from pathlib import Path
 
-from edc_constants.constants import IGNORE
 from edc_test_utils import DefaultTestSettings, func_main
 
 app_name = "edc_auth"
-base_dir = dirname(abspath(__file__))
+base_dir = Path(__file__).absolute().parent
 
 project_settings = DefaultTestSettings(
     calling_file=__file__,
-    EDC_NAVBAR_VERIFY_ON_LOAD=IGNORE,
+    SILENCED_SYSTEM_CHECKS=[
+        "edc_sites.E001",
+        "edc_sites.E002",
+        "sites.E101",
+        "edc_navbar.E002",
+        "edc_navbar.E003",
+    ],
     EDC_AUTH_CODENAMES_WARN_ONLY=True,
     EDC_AUTH_SKIP_SITE_AUTHS=True,
     EDC_AUTH_SKIP_AUTH_UPDATER=True,
     BASE_DIR=base_dir,
     APP_NAME=app_name,
+    SUBJECT_VISIT_MODEL="edc_visit_tracking.subjectvisit",
     add_dashboard_middleware=True,
     add_lab_dashboard_middleware=True,
     use_test_urls=True,
